Coverage report

File | class | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | --- | ---
src/derivepassphrase/__init__.py | Vault | 99 | 0 | 0 | 51 | 0 | 100.000%
src/derivepassphrase/__init__.py | (no class) | 35 | 0 | 0 | 0 | 0 | 100.000%
src/derivepassphrase/cli.py | OptionGroupOption | 2 | 0 | 1 | 0 | 0 | 100.000%
src/derivepassphrase/cli.py | CommandWithHelpGroups | 24 | 0 | 0 | 16 | 0 | 100.000%
src/derivepassphrase/cli.py | (no class) | 317 | 0 | 10 | 161 | 0 | 100.000%
src/derivepassphrase/types.py | (no class) | 54 | 0 | 0 | 34 | 4 | 95.455%
src/sequin/__init__.py | Sequin | 81 | 0 | 0 | 44 | 0 | 100.000%
src/sequin/__init__.py | (no class) | 16 | 0 | 0 | 0 | 0 | 100.000%
src/ssh_agent_client/__init__.py | SSHAgentClient | 82 | 0 | 2 | 32 | 0 | 100.000%
src/ssh_agent_client/__init__.py | (no class) | 29 | 0 | 0 | 0 | 0 | 100.000%
src/ssh_agent_client/types.py | (no class) | 13 | 0 | 0 | 0 | 0 | 100.000%
tests/__init__.py | (no class) | 58 | 0 | 8 | 10 | 0 | 100.000%
tests/test_derivepassphrase.py | TestVault | 56 | 0 | 0 | 24 | 0 | 100.000%
tests/test_derivepassphrase.py | (no class) | 37 | 0 | 0 | 0 | 0 | 100.000%
tests/test_derivepassphrase_cli.py | TestCLI | 190 | 0 | 4 | 68 | 0 | 100.000%
tests/test_derivepassphrase_cli.py | TestCLIUtils | 65 | 0 | 4 | 16 | 1 | 98.765%
tests/test_derivepassphrase_cli.py | (no class) | 101 | 0 | 0 | 10 | 0 | 100.000%
tests/test_derivepassphrase_typing.py | (no class) | 8 | 0 | 0 | 0 | 0 | 100.000%
tests/test_sequin.py | TestStaticFunctionality | 3 | 0 | 0 | 2 | 0 | 100.000%
tests/test_sequin.py | TestSequin | 37 | 0 | 0 | 12 | 0 | 100.000%
tests/test_sequin.py | (no class) | 16 | 0 | 0 | 0 | 0 | 100.000%
tests/test_ssh_agent_client.py | TestStaticFunctionality | 28 | 0 | 0 | 16 | 0 | 100.000%
tests/test_ssh_agent_client.py | TestAgentInteraction | 86 | 0 | 10 | 40 | 0 | 100.000%
tests/test_ssh_agent_client.py | TestAgentInteraction.test_310_truncated_server_response.PseudoSocket | 2 | 0 | 0 | 0 | 0 | 100.000%
tests/test_ssh_agent_client.py | (no class) | 50 | 0 | 0 | 4 | 0 | 100.000%
Total |  | 1489 | 0 | 39 | 540 | 5 | 99.754%

No items found using the specified filter.

16 empty classes skipped.